Documentation
¶
Overview ¶
Package fixtvals provides common types for fixtures of the enterpriseconnectors package.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type FixtValue ¶
type FixtValue struct {
PolicyParams
lacrosfixt.FixtValue
}
FixtValue is a type that embeds both PolicyParams and lacrosfixt.FixtValue
type PolicyParams ¶
type PolicyParams struct {
AllowsImmediateDelivery bool // specifies whether immediate delivery of files is allowed
AllowsUnscannableFiles bool // specifies whether unscannable files (large or encrypted) are allowed
ScansEnabledForDownload bool // specifies whether malware and dlp scans are enabled for download
ScansEnabledForUpload bool // specifies whether malware and dlp scans are enabled for upload
}
PolicyParams entail parameters describing the set policy for a user.
Click to show internal directories.
Click to hide internal directories.