Documentation
¶
Overview ¶
Package ippprint implements printing with IPP options.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func WithJobPassword ¶
WithJobPassword properly formats a job-password option.
func WithResolution ¶
WithResolution properly formats a printer-resolution option.
Types ¶
type Params ¶
type Params struct {
PPDFile string // Name of the ppd used to print the job.
PrintFile string // The file to print.
ExpectedFile string // The file output should be compared to.
Options []string // Options to be passed to the filter to change output.
}
Params struct used by all ipp print tests for parameterized tests.
Click to show internal directories.
Click to hide internal directories.