Documentation
¶
Overview ¶
Package intelfwextractor extracts the fw dump and validate its contents.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type DevcoreHeader ¶
DevcoreHeader is a struct that contains the fw dump header information.
type MandatoryFWDumpFiles ¶
MandatoryFWDumpFiles are the mandaotry files that must exists in the fw dump to be valid. Refer to http://b/169152720#comment28 for more information. These files are only mandatory for the Memory API Magic firmware dumps. csr.lst (mandatory) header type 1 monitor.lst (mandatory) header type 5 dccm_lmac.lst (mandatory) header type of 9
type VHeader ¶
VHeader is a struct that contains the memory type and address of a value in a TLV header.
type VYoYoInfoHeader ¶
type VYoYoInfoHeader struct {
Version uint32
TriggerTimepoint uint32
TriggerReason uint32
ExternalCfgState uint32
VerType uint32
VerSubtype uint32
HwStep uint32
HwType uint32
RfIDFlavor uint32
RfIDDash uint32
RfIDStep uint32
RfIDType uint32
LmacMajor uint32
LmacMinor uint32
UmacMajor uint32
UmacMinor uint32
FwMonMode uint32
RegionsMask uint64
}
VYoYoInfoHeader is a struct for reading the value of a YoYo TLV header.