Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var WilcoDtcSupportdAPI = NewPrecondition("supportd_api", SystemState{ WilcoDTCDaemonRunning: true, WilcoDTCVMRunning: true, VMConfig: wilco.VMConfig{ StartProcesses: false, TestDBusConfig: false, }, })
WilcoDtcSupportdAPI Precondition sets up the system to test the API provided in wilco_dtc_supportd.proto.
Functions ¶
func NewPrecondition ¶
func NewPrecondition(suffix string, state SystemState) *preImpl
NewPrecondition creates a new precondition that can be shared by tests that reqire a combination of the Wilco DTC Daemon and VM to be running.
Types ¶
type SystemState ¶
type SystemState struct {
// WilcoDTCDaemonRunning ensures the Wilco DTC Support Daemon is running.
WilcoDTCDaemonRunning bool
// WilcoDTCVMRunning ensures the Wilco DTC VM is running.
WilcoDTCVMRunning bool
// VMConfig is the configuration for the DTC VM.
VMConfig wilco.VMConfig
}
SystemState describes the desired system state.
Click to show internal directories.
Click to hide internal directories.