Documentation
¶
Overview ¶
Package nearbyfixture contains fixtures for Nearby Share tests.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewNearbyShareAndroid ¶
func NewNearbyShareAndroid(androidDataUsage nearbysnippet.DataUsage, androidVisibility nearbysnippet.Visibility, androidNearbyChannel channel) testing.FixtureImpl
NewNearbyShareAndroid creates a fixture that sets up an Android device for Nearby Share.
func NewNearbyShareFixture ¶
func NewNearbyShareFixture(opts fixtureOptions) testing.FixtureImpl
NewNearbyShareFixture creates a new implementation of the Nearby Share fixture.
func NewNearbyShareLogin ¶
func NewNearbyShareLogin(arcEnabled, backgroundScanningEnabled, useAndroidAccount bool, m mediums) testing.FixtureImpl
NewNearbyShareLogin creates a fixture that logs in and enables Nearby Share. Note that nearbyShareGAIALogin inherits from nearbyShareAndroidSetup.
Types ¶
type FixtData ¶
type FixtData struct {
// Chrome is the running chrome instance.
Chrome *chrome.Chrome
// TestConn is a connection to the test extension.
TestConn *chrome.TestConn
// CrOSUsername is the user account logged into Chrome.
CrOSUsername string
// CrOSDeviceName is the CrOS device name configured for Nearby Share.
CrOSDeviceName string
// AndroidDevice is an object for interacting with the connected Android device's Snippet Library.
AndroidDevice *nearbysnippet.AndroidNearbyDevice
// AndroidDeviceName is the Android device name configured for Nearby Share.
AndroidDeviceName string
// AndroidLoggedIn is true if Android is logged in.
AndroidLoggedIn bool
// AndroidUsername is the GAIA account logged in on Android.
AndroidUsername string
// AndroidNearbyChannel is the channel of Nearby the phone is using.
AndroidNearbyChannel channel
// ARC is the ARC instance, if enabled.
ARC *arc.ARC
}
FixtData holds information made available to tests that specify this Fixture.
Click to show internal directories.
Click to hide internal directories.