Documentation
¶
Overview ¶
Package trace provides common code to replay graphics trace files.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var HwDepsStable = hwdep.D(hwdep.Model(modelAllowlist...), crostini.CrostiniMinDiskSizeCond)
HwDepsStable is hardwareDeps condition that stable to run trace tests.
var HwDepsUnstable = hwdep.D(hwdep.SkipOnModel(modelAllowlist...), crostini.CrostiniMinDiskSizeCond)
HwDepsUnstable is hardwareDeps condition that unstable to run trace tests.
Functions ¶
func RunTraceReplayTest ¶
func RunTraceReplayTest(ctx context.Context, resultDir string, cloudStorage *testing.CloudStorage, guest IGuestOS, group *comm.TestGroupConfig, testVars *comm.TestVars) error
RunTraceReplayTest starts the VM and replays all the traces in the test config.
Types ¶
type IGuestOS ¶
type IGuestOS interface {
// Command returns a testexec.Cmd with a vsh command that will run in the guest.
Command(ctx context.Context, vshArgs ...string) *testexec.Cmd
// GetBinPath returns the recommended binaries path in the guest OS.
// The trace_replay binary will be uploaded into this directory.
GetBinPath() string
// GetTempPath returns the recommended temp path in the guest OS. This directory
// can be used to store downloaded artifacts and other temp files.
GetTempPath() string
}
IGuestOS interface is used to unify various VM guest OS access
Directories
¶
| Path | Synopsis |
|---|---|
|
Package comm contains trace_replay application host <-> guest communication protocol structures.
|
Package comm contains trace_replay application host <-> guest communication protocol structures. |
|
Package guestos provides VM guest OS related primitives.
|
Package guestos provides VM guest OS related primitives. |
Click to show internal directories.
Click to hide internal directories.