Documentation
¶
Overview ¶
Package kerberos contains details about Kerberos setup that is used in testing.
Package kerberos contains details about Kerberos setup that is used in testing.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Configuration ¶
type Configuration struct {
// KerberosDomain domain of the hosting server.
KerberosDomain string
// ServerAllowlist server name for integrated authorization.
ServerAllowlist string
// WebsiteAddress website address that is guarded by Kerberos.
WebsiteAddress string
// KerberosAccount is constructed in a following way username@domain.
KerberosAccount string
// Folder is the name of the directory that is part of RemoteFileSystemURI.
Folder string
// RemoteFileSystemURI is a identifier of remote file system that is
// guarded by Kerberos.
RemoteFileSystemURI string
// File is the name of the file that is expected on samba mount.
File string
// RealmsConfig is an advanced configuration that helps finding the kdc on the KerberosDomain.
RealmsConfig string
}
Configuration contains all necessary data needed for test to access Kerberos infrastructure.
func ConstructConfig ¶
func ConstructConfig(kerberosDomain, username string) *Configuration
ConstructConfig prepares all necessary constants that are used by tests.
Click to show internal directories.
Click to hide internal directories.