Documentation
¶
Overview ¶
Package apps provides types shared among specific VDI implementations.
Index ¶
Constants ¶
const VDILoginTimeout = time.Minute
VDILoginTimeout is the timeout for login to VDI applications.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type VDIInt ¶
type VDIInt interface {
Init(s *testing.FixtState, d *uidetection.Context)
Login(ctx context.Context, k *input.KeyboardEventWriter, cfg *VDILoginConfig) error
WaitForMainScreenVisible(ctx context.Context) error
SearchAndOpenApplication(ctx context.Context, k *input.KeyboardEventWriter, appName string, checkIfOpened func(context.Context) error) uiauto.Action
ResetSearch(ctx context.Context, k *input.KeyboardEventWriter) error
}
VDIInt is an interface for VDI application providing common way to connect to VDI application and other shared functionality.
type VDILoginConfig ¶
VDILoginConfig holds data necessary to login to a specific VDI application.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package citrix holds the implementation of the /vdi/apps/vdiconnector.VDIInt interface for Citrix application.
|
Package citrix holds the implementation of the /vdi/apps/vdiconnector.VDIInt interface for Citrix application. |
|
Package vmware holds the implementation of the /vdi/apps/vdiconnector.VDIInt interface for Vmware application.
|
Package vmware holds the implementation of the /vdi/apps/vdiconnector.VDIInt interface for Vmware application. |
Click to show internal directories.
Click to hide internal directories.