Documentation
¶
Overview ¶
Package version provides set of util functions used to work with ARC version properties.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BuildDescriptor ¶
type BuildDescriptor struct {
// true in case built by ab/
Official bool
// ab/buildID
BuildID string
// build type e.g. user, userdebug
BuildType string
// cpu abi e.g. x86_64, x86, arm
CPUAbi string
}
BuildDescriptor contains essential parametrs of ARC Android image taken from test device.
func GetBuildDescriptorRemotely ¶
func GetBuildDescriptorRemotely(ctx context.Context, dut *dut.DUT, vmEnabled bool) (*BuildDescriptor, error)
GetBuildDescriptorRemotely gets ARC build properties from the device, parses for build ID, ABI, and returns these fields as a combined string. It also return whether this is official build.
Click to show internal directories.
Click to hide internal directories.