Documentation
¶
Overview ¶
Package params contains helpers to load the configuration of the device and the expectations from Omaha.
Index ¶
Constants ¶
const DefaultAppID = "{87efface-864d-49a5-9bb3-4b050a7c227a}"
DefaultAppID is used if no device specific app id is found.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Configuration ¶
type Configuration struct {
// OldVersion is a version older that then any available stable and should
// update to the latest stable without any stepping stone.
OldVersion string
// ChromeOSVersionFromMilestone maps Chrome milestones to Chrome OS version prefixes.
ChromeOSVersionFromMilestone map[int]int
// CurrentStableChrome is the current stable milestone of Chrome OS.
CurrentStableChrome int
// CurrentStableChrome is the next stable milestone of Chrome OS.
NextStableChrome int
// CurrentChromeOSLTS is the current Chrome OS LTS milestone.
CurrentChromeOSLTS int
// CurrentChromeOSLTSMinor is the first LTS only minor version.
CurrentChromeOSLTSMinor int
}
Configuration contains the expected state of Omaha.
func (*Configuration) DumpToFile ¶
func (d *Configuration) DumpToFile(path string) error
DumpToFile writes the device parameters to a file.
type Device ¶
Device contains the device specific parameters used by update_engine.
func (*Device) DumpToFile ¶
DumpToFile writes the device parameters to a file.
type FixtData ¶
type FixtData struct {
Device *Device
Config *Configuration
}
FixtData is the data made available by the fixture for its tests. Contains DUT parameters and the current configuration.
Click to show internal directories.
Click to hide internal directories.