Documentation
¶
Overview ¶
Package cmd contains the interface for running commands in packages such as iw and ping.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type RemoteCmdRunner ¶
type RemoteCmdRunner struct {
Host *ssh.Conn
NoLogOnError bool // Default false: dump log on error.
}
RemoteCmdRunner is the object used for running remote commands.
Click to show internal directories.
Click to hide internal directories.