Documentation
¶
Overview ¶
Package apps provides all apps related types compiled from protobuf.
Index ¶
- Variables
- func RegisterAppsServiceServer(s *grpc.Server, srv AppsServiceServer)
- type App
- type AppsServiceClient
- type AppsServiceServer
- type LaunchAppRequest
- func (*LaunchAppRequest) Descriptor() ([]byte, []int)deprecated
- func (x *LaunchAppRequest) GetAppName() string
- func (x *LaunchAppRequest) GetTimeoutSecs() int32
- func (*LaunchAppRequest) ProtoMessage()
- func (x *LaunchAppRequest) ProtoReflect() protoreflect.Message
- func (x *LaunchAppRequest) Reset()
- func (x *LaunchAppRequest) String() string
- type UnimplementedAppsServiceServer
- func (*UnimplementedAppsServiceServer) GetPrimaryBrowser(context.Context, *empty.Empty) (*App, error)
- func (*UnimplementedAppsServiceServer) LaunchApp(context.Context, *LaunchAppRequest) (*empty.Empty, error)
- func (*UnimplementedAppsServiceServer) LaunchPrimaryBrowser(context.Context, *empty.Empty) (*App, error)
Constants ¶
This section is empty.
Variables ¶
var File_apps_service_proto protoreflect.FileDescriptor
Functions ¶
func RegisterAppsServiceServer ¶
func RegisterAppsServiceServer(s *grpc.Server, srv AppsServiceServer)
Types ¶
type App ¶
type App struct {
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
App represents a chromeOS app. More fields may be added as required.
func (*App) Descriptor
deprecated
func (*App) ProtoMessage ¶
func (*App) ProtoMessage()
func (*App) ProtoReflect ¶
func (x *App) ProtoReflect() protoreflect.Message
type AppsServiceClient ¶
type AppsServiceClient interface {
// LaunchApp requests to launch an app.
LaunchApp(ctx context.Context, in *LaunchAppRequest, opts ...grpc.CallOption) (*empty.Empty, error)
// GetPrimaryBrowser returns the app that is set to the primary browser.
// This can be used to tell whether Lacros is enabled.
GetPrimaryBrowser(ctx context.Context, in *empty.Empty, opts ...grpc.CallOption) (*App, error)
// LaunchPrimaryBrowser launches the primary browser, and returns it.
LaunchPrimaryBrowser(ctx context.Context, in *empty.Empty, opts ...grpc.CallOption) (*App, error)
}
AppsServiceClient is the client API for AppsService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
func NewAppsServiceClient ¶
func NewAppsServiceClient(cc grpc.ClientConnInterface) AppsServiceClient
type AppsServiceServer ¶
type AppsServiceServer interface {
// LaunchApp requests to launch an app.
LaunchApp(context.Context, *LaunchAppRequest) (*empty.Empty, error)
// GetPrimaryBrowser returns the app that is set to the primary browser.
// This can be used to tell whether Lacros is enabled.
GetPrimaryBrowser(context.Context, *empty.Empty) (*App, error)
// LaunchPrimaryBrowser launches the primary browser, and returns it.
LaunchPrimaryBrowser(context.Context, *empty.Empty) (*App, error)
}
AppsServiceServer is the server API for AppsService service.
type LaunchAppRequest ¶
type LaunchAppRequest struct {
AppName string `protobuf:"bytes,1,opt,name=app_name,json=appName,proto3" json:"app_name,omitempty"`
// Defaults to 1 minute.
TimeoutSecs int32 `protobuf:"varint,2,opt,name=timeout_secs,json=timeoutSecs,proto3" json:"timeout_secs,omitempty"`
// contains filtered or unexported fields
}
LaunchAppRequest requests starting an app.
func (*LaunchAppRequest) Descriptor
deprecated
func (*LaunchAppRequest) Descriptor() ([]byte, []int)
Deprecated: Use LaunchAppRequest.ProtoReflect.Descriptor instead.
func (*LaunchAppRequest) GetAppName ¶
func (x *LaunchAppRequest) GetAppName() string
func (*LaunchAppRequest) GetTimeoutSecs ¶
func (x *LaunchAppRequest) GetTimeoutSecs() int32
func (*LaunchAppRequest) ProtoMessage ¶
func (*LaunchAppRequest) ProtoMessage()
func (*LaunchAppRequest) ProtoReflect ¶
func (x *LaunchAppRequest) ProtoReflect() protoreflect.Message
func (*LaunchAppRequest) Reset ¶
func (x *LaunchAppRequest) Reset()
func (*LaunchAppRequest) String ¶
func (x *LaunchAppRequest) String() string
type UnimplementedAppsServiceServer ¶
type UnimplementedAppsServiceServer struct {
}
UnimplementedAppsServiceServer can be embedded to have forward compatible implementations.
func (*UnimplementedAppsServiceServer) GetPrimaryBrowser ¶
func (*UnimplementedAppsServiceServer) LaunchApp ¶
func (*UnimplementedAppsServiceServer) LaunchApp(context.Context, *LaunchAppRequest) (*empty.Empty, error)
func (*UnimplementedAppsServiceServer) LaunchPrimaryBrowser ¶
Click to show internal directories.
Click to hide internal directories.