Documentation
¶
Overview ¶
Package inputs provides all inputs related types compiled from protobuf.
Index ¶
- Variables
- func RegisterKeyboardServiceServer(s *grpc.Server, srv KeyboardServiceServer)
- func RegisterTouchpadServiceServer(s *grpc.Server, srv TouchpadServiceServer)
- func RegisterTouchscreenServiceServer(s *grpc.Server, srv TouchscreenServiceServer)
- type AccelPressRequest
- type AccelReleaseRequest
- func (*AccelReleaseRequest) Descriptor() ([]byte, []int)deprecated
- func (x *AccelReleaseRequest) GetKey() string
- func (*AccelReleaseRequest) ProtoMessage()
- func (x *AccelReleaseRequest) ProtoReflect() protoreflect.Message
- func (x *AccelReleaseRequest) Reset()
- func (x *AccelReleaseRequest) String() string
- type AccelRequest
- type FindPhysicalTouchpadResponse
- func (*FindPhysicalTouchpadResponse) Descriptor() ([]byte, []int)deprecated
- func (x *FindPhysicalTouchpadResponse) GetPath() string
- func (*FindPhysicalTouchpadResponse) ProtoMessage()
- func (x *FindPhysicalTouchpadResponse) ProtoReflect() protoreflect.Message
- func (x *FindPhysicalTouchpadResponse) Reset()
- func (x *FindPhysicalTouchpadResponse) String() string
- type FindPhysicalTouchscreenResponse
- func (*FindPhysicalTouchscreenResponse) Descriptor() ([]byte, []int)deprecated
- func (x *FindPhysicalTouchscreenResponse) GetPath() string
- func (*FindPhysicalTouchscreenResponse) ProtoMessage()
- func (x *FindPhysicalTouchscreenResponse) ProtoReflect() protoreflect.Message
- func (x *FindPhysicalTouchscreenResponse) Reset()
- func (x *FindPhysicalTouchscreenResponse) String() string
- type KeyboardServiceClient
- type KeyboardServiceServer
- type TouchpadServiceClient
- type TouchpadServiceServer
- type TouchscreenServiceClient
- type TouchscreenServiceServer
- type TypeRequest
- type UnimplementedKeyboardServiceServer
- func (*UnimplementedKeyboardServiceServer) Accel(context.Context, *AccelRequest) (*empty.Empty, error)
- func (*UnimplementedKeyboardServiceServer) AccelPress(context.Context, *AccelPressRequest) (*empty.Empty, error)
- func (*UnimplementedKeyboardServiceServer) AccelRelease(context.Context, *AccelReleaseRequest) (*empty.Empty, error)
- func (*UnimplementedKeyboardServiceServer) Type(context.Context, *TypeRequest) (*empty.Empty, error)
- type UnimplementedTouchpadServiceServer
- func (*UnimplementedTouchpadServiceServer) CloseChrome(context.Context, *empty.Empty) (*empty.Empty, error)
- func (*UnimplementedTouchpadServiceServer) FindPhysicalTouchpad(context.Context, *empty.Empty) (*FindPhysicalTouchpadResponse, error)
- func (*UnimplementedTouchpadServiceServer) NewChrome(context.Context, *empty.Empty) (*empty.Empty, error)
- func (*UnimplementedTouchpadServiceServer) TouchpadSwipe(context.Context, *empty.Empty) (*empty.Empty, error)
- type UnimplementedTouchscreenServiceServer
- func (*UnimplementedTouchscreenServiceServer) CloseChrome(context.Context, *empty.Empty) (*empty.Empty, error)
- func (*UnimplementedTouchscreenServiceServer) FindPhysicalTouchscreen(context.Context, *empty.Empty) (*FindPhysicalTouchscreenResponse, error)
- func (*UnimplementedTouchscreenServiceServer) NewChrome(context.Context, *empty.Empty) (*empty.Empty, error)
- func (*UnimplementedTouchscreenServiceServer) TouchscreenTap(context.Context, *empty.Empty) (*empty.Empty, error)
Constants ¶
This section is empty.
Variables ¶
var File_keyboard_service_proto protoreflect.FileDescriptor
var File_touch_pad_service_proto protoreflect.FileDescriptor
var File_touch_screen_service_proto protoreflect.FileDescriptor
Functions ¶
func RegisterKeyboardServiceServer ¶
func RegisterKeyboardServiceServer(s *grpc.Server, srv KeyboardServiceServer)
func RegisterTouchpadServiceServer ¶
func RegisterTouchpadServiceServer(s *grpc.Server, srv TouchpadServiceServer)
func RegisterTouchscreenServiceServer ¶
func RegisterTouchscreenServiceServer(s *grpc.Server, srv TouchscreenServiceServer)
Types ¶
type AccelPressRequest ¶
type AccelPressRequest struct {
Key string `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
// contains filtered or unexported fields
}
func (*AccelPressRequest) Descriptor
deprecated
func (*AccelPressRequest) Descriptor() ([]byte, []int)
Deprecated: Use AccelPressRequest.ProtoReflect.Descriptor instead.
func (*AccelPressRequest) GetKey ¶
func (x *AccelPressRequest) GetKey() string
func (*AccelPressRequest) ProtoMessage ¶
func (*AccelPressRequest) ProtoMessage()
func (*AccelPressRequest) ProtoReflect ¶
func (x *AccelPressRequest) ProtoReflect() protoreflect.Message
func (*AccelPressRequest) Reset ¶
func (x *AccelPressRequest) Reset()
func (*AccelPressRequest) String ¶
func (x *AccelPressRequest) String() string
type AccelReleaseRequest ¶
type AccelReleaseRequest struct {
Key string `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
// contains filtered or unexported fields
}
func (*AccelReleaseRequest) Descriptor
deprecated
func (*AccelReleaseRequest) Descriptor() ([]byte, []int)
Deprecated: Use AccelReleaseRequest.ProtoReflect.Descriptor instead.
func (*AccelReleaseRequest) GetKey ¶
func (x *AccelReleaseRequest) GetKey() string
func (*AccelReleaseRequest) ProtoMessage ¶
func (*AccelReleaseRequest) ProtoMessage()
func (*AccelReleaseRequest) ProtoReflect ¶
func (x *AccelReleaseRequest) ProtoReflect() protoreflect.Message
func (*AccelReleaseRequest) Reset ¶
func (x *AccelReleaseRequest) Reset()
func (*AccelReleaseRequest) String ¶
func (x *AccelReleaseRequest) String() string
type AccelRequest ¶
type AccelRequest struct {
Key string `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
// contains filtered or unexported fields
}
func (*AccelRequest) Descriptor
deprecated
func (*AccelRequest) Descriptor() ([]byte, []int)
Deprecated: Use AccelRequest.ProtoReflect.Descriptor instead.
func (*AccelRequest) GetKey ¶
func (x *AccelRequest) GetKey() string
func (*AccelRequest) ProtoMessage ¶
func (*AccelRequest) ProtoMessage()
func (*AccelRequest) ProtoReflect ¶
func (x *AccelRequest) ProtoReflect() protoreflect.Message
func (*AccelRequest) Reset ¶
func (x *AccelRequest) Reset()
func (*AccelRequest) String ¶
func (x *AccelRequest) String() string
type FindPhysicalTouchpadResponse ¶
type FindPhysicalTouchpadResponse struct {
Path string `protobuf:"bytes,1,opt,name=path,proto3" json:"path,omitempty"`
// contains filtered or unexported fields
}
FindPhysicalTouchpadResponse provides the path to /dev/input/event* for a physical trackpad.
func (*FindPhysicalTouchpadResponse) Descriptor
deprecated
func (*FindPhysicalTouchpadResponse) Descriptor() ([]byte, []int)
Deprecated: Use FindPhysicalTouchpadResponse.ProtoReflect.Descriptor instead.
func (*FindPhysicalTouchpadResponse) GetPath ¶
func (x *FindPhysicalTouchpadResponse) GetPath() string
func (*FindPhysicalTouchpadResponse) ProtoMessage ¶
func (*FindPhysicalTouchpadResponse) ProtoMessage()
func (*FindPhysicalTouchpadResponse) ProtoReflect ¶
func (x *FindPhysicalTouchpadResponse) ProtoReflect() protoreflect.Message
func (*FindPhysicalTouchpadResponse) Reset ¶
func (x *FindPhysicalTouchpadResponse) Reset()
func (*FindPhysicalTouchpadResponse) String ¶
func (x *FindPhysicalTouchpadResponse) String() string
type FindPhysicalTouchscreenResponse ¶
type FindPhysicalTouchscreenResponse struct {
Path string `protobuf:"bytes,1,opt,name=path,proto3" json:"path,omitempty"`
// contains filtered or unexported fields
}
FindPhysicalTouchscreenResponse provides the path to /dev/input/event* for a physical trackscreen.
func (*FindPhysicalTouchscreenResponse) Descriptor
deprecated
func (*FindPhysicalTouchscreenResponse) Descriptor() ([]byte, []int)
Deprecated: Use FindPhysicalTouchscreenResponse.ProtoReflect.Descriptor instead.
func (*FindPhysicalTouchscreenResponse) GetPath ¶
func (x *FindPhysicalTouchscreenResponse) GetPath() string
func (*FindPhysicalTouchscreenResponse) ProtoMessage ¶
func (*FindPhysicalTouchscreenResponse) ProtoMessage()
func (*FindPhysicalTouchscreenResponse) ProtoReflect ¶
func (x *FindPhysicalTouchscreenResponse) ProtoReflect() protoreflect.Message
func (*FindPhysicalTouchscreenResponse) Reset ¶
func (x *FindPhysicalTouchscreenResponse) Reset()
func (*FindPhysicalTouchscreenResponse) String ¶
func (x *FindPhysicalTouchscreenResponse) String() string
type KeyboardServiceClient ¶
type KeyboardServiceClient interface {
// Type injects key events suitable for generating the string s.
// Only characters that can be typed using a QWERTY keyboard are supported,
// and the current keyboard layout must be QWERTY. The left Shift key is
// automatically pressed and released for uppercase letters or other
// characters that can be typed using Shift.
Type(ctx context.Context, in *TypeRequest, opts ...grpc.CallOption) (*empty.Empty, error)
// Accel injects a sequence of key events simulating the accelerator (a.k.a.
// hotkey) described by s being typed.
// Accelerators are described as a sequence of '+'-separated, case-insensitive
// key characters or names. In addition to non-whitespace characters that are
// present on a QWERTY keyboard, the following key names may be used:
// Modifiers: "Ctrl", "Alt", "Search", "Shift"
// Whitespace: "Enter", "Space", "Tab", "Backspace"
// Function keys: "F1", "F2", ..., "F12"
// "Shift" must be included for keys that are typed using Shift; for example,
// use "Ctrl+Shift+/" rather than "Ctrl+?".
Accel(ctx context.Context, in *AccelRequest, opts ...grpc.CallOption) (*empty.Empty, error)
// AccelPress injects a sequence of key events simulating pressing the
// accelerator (a.k.a. hotkey) described by s.
AccelPress(ctx context.Context, in *AccelPressRequest, opts ...grpc.CallOption) (*empty.Empty, error)
// AccelRelease injects a sequence of key events simulating release the
// accelerator (a.k.a. hotkey) described by s.
AccelRelease(ctx context.Context, in *AccelReleaseRequest, opts ...grpc.CallOption) (*empty.Empty, error)
}
KeyboardServiceClient is the client API for KeyboardService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
func NewKeyboardServiceClient ¶
func NewKeyboardServiceClient(cc grpc.ClientConnInterface) KeyboardServiceClient
type KeyboardServiceServer ¶
type KeyboardServiceServer interface {
// Type injects key events suitable for generating the string s.
// Only characters that can be typed using a QWERTY keyboard are supported,
// and the current keyboard layout must be QWERTY. The left Shift key is
// automatically pressed and released for uppercase letters or other
// characters that can be typed using Shift.
Type(context.Context, *TypeRequest) (*empty.Empty, error)
// Accel injects a sequence of key events simulating the accelerator (a.k.a.
// hotkey) described by s being typed.
// Accelerators are described as a sequence of '+'-separated, case-insensitive
// key characters or names. In addition to non-whitespace characters that are
// present on a QWERTY keyboard, the following key names may be used:
// Modifiers: "Ctrl", "Alt", "Search", "Shift"
// Whitespace: "Enter", "Space", "Tab", "Backspace"
// Function keys: "F1", "F2", ..., "F12"
// "Shift" must be included for keys that are typed using Shift; for example,
// use "Ctrl+Shift+/" rather than "Ctrl+?".
Accel(context.Context, *AccelRequest) (*empty.Empty, error)
// AccelPress injects a sequence of key events simulating pressing the
// accelerator (a.k.a. hotkey) described by s.
AccelPress(context.Context, *AccelPressRequest) (*empty.Empty, error)
// AccelRelease injects a sequence of key events simulating release the
// accelerator (a.k.a. hotkey) described by s.
AccelRelease(context.Context, *AccelReleaseRequest) (*empty.Empty, error)
}
KeyboardServiceServer is the server API for KeyboardService service.
type TouchpadServiceClient ¶
type TouchpadServiceClient interface {
// NewChrome logs into a Chrome session as a fake user. CloseChrome must be called later
// to clean up the associated resources.
NewChrome(ctx context.Context, in *empty.Empty, opts ...grpc.CallOption) (*empty.Empty, error)
// CloseChrome releases the resources obtained by NewChrome.
CloseChrome(ctx context.Context, in *empty.Empty, opts ...grpc.CallOption) (*empty.Empty, error)
// FindPhysicalTouchpad finds /dev/input/event* file for a physical touchpad.
FindPhysicalTouchpad(ctx context.Context, in *empty.Empty, opts ...grpc.CallOption) (*FindPhysicalTouchpadResponse, error)
// TouchpadSwipe injects a swipe event to the touchpad.
TouchpadSwipe(ctx context.Context, in *empty.Empty, opts ...grpc.CallOption) (*empty.Empty, error)
}
TouchpadServiceClient is the client API for TouchpadService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
func NewTouchpadServiceClient ¶
func NewTouchpadServiceClient(cc grpc.ClientConnInterface) TouchpadServiceClient
type TouchpadServiceServer ¶
type TouchpadServiceServer interface {
// NewChrome logs into a Chrome session as a fake user. CloseChrome must be called later
// to clean up the associated resources.
NewChrome(context.Context, *empty.Empty) (*empty.Empty, error)
// CloseChrome releases the resources obtained by NewChrome.
CloseChrome(context.Context, *empty.Empty) (*empty.Empty, error)
// FindPhysicalTouchpad finds /dev/input/event* file for a physical touchpad.
FindPhysicalTouchpad(context.Context, *empty.Empty) (*FindPhysicalTouchpadResponse, error)
// TouchpadSwipe injects a swipe event to the touchpad.
TouchpadSwipe(context.Context, *empty.Empty) (*empty.Empty, error)
}
TouchpadServiceServer is the server API for TouchpadService service.
type TouchscreenServiceClient ¶
type TouchscreenServiceClient interface {
// NewChrome logs into a Chrome session as a fake user. CloseChrome must be called later
// to clean up the associated resources.
NewChrome(ctx context.Context, in *empty.Empty, opts ...grpc.CallOption) (*empty.Empty, error)
// CloseChrome releases the resources obtained by NewChrome.
CloseChrome(ctx context.Context, in *empty.Empty, opts ...grpc.CallOption) (*empty.Empty, error)
// FindPhysicalTouchscreen finds /dev/input/event* file for a physical touchscreen.
FindPhysicalTouchscreen(ctx context.Context, in *empty.Empty, opts ...grpc.CallOption) (*FindPhysicalTouchscreenResponse, error)
// TouchscreenTap injects a tap event to the touch screen.
TouchscreenTap(ctx context.Context, in *empty.Empty, opts ...grpc.CallOption) (*empty.Empty, error)
}
TouchscreenServiceClient is the client API for TouchscreenService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
func NewTouchscreenServiceClient ¶
func NewTouchscreenServiceClient(cc grpc.ClientConnInterface) TouchscreenServiceClient
type TouchscreenServiceServer ¶
type TouchscreenServiceServer interface {
// NewChrome logs into a Chrome session as a fake user. CloseChrome must be called later
// to clean up the associated resources.
NewChrome(context.Context, *empty.Empty) (*empty.Empty, error)
// CloseChrome releases the resources obtained by NewChrome.
CloseChrome(context.Context, *empty.Empty) (*empty.Empty, error)
// FindPhysicalTouchscreen finds /dev/input/event* file for a physical touchscreen.
FindPhysicalTouchscreen(context.Context, *empty.Empty) (*FindPhysicalTouchscreenResponse, error)
// TouchscreenTap injects a tap event to the touch screen.
TouchscreenTap(context.Context, *empty.Empty) (*empty.Empty, error)
}
TouchscreenServiceServer is the server API for TouchscreenService service.
type TypeRequest ¶
type TypeRequest struct {
Key string `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
// contains filtered or unexported fields
}
func (*TypeRequest) Descriptor
deprecated
func (*TypeRequest) Descriptor() ([]byte, []int)
Deprecated: Use TypeRequest.ProtoReflect.Descriptor instead.
func (*TypeRequest) GetKey ¶
func (x *TypeRequest) GetKey() string
func (*TypeRequest) ProtoMessage ¶
func (*TypeRequest) ProtoMessage()
func (*TypeRequest) ProtoReflect ¶
func (x *TypeRequest) ProtoReflect() protoreflect.Message
func (*TypeRequest) Reset ¶
func (x *TypeRequest) Reset()
func (*TypeRequest) String ¶
func (x *TypeRequest) String() string
type UnimplementedKeyboardServiceServer ¶
type UnimplementedKeyboardServiceServer struct {
}
UnimplementedKeyboardServiceServer can be embedded to have forward compatible implementations.
func (*UnimplementedKeyboardServiceServer) Accel ¶
func (*UnimplementedKeyboardServiceServer) Accel(context.Context, *AccelRequest) (*empty.Empty, error)
func (*UnimplementedKeyboardServiceServer) AccelPress ¶
func (*UnimplementedKeyboardServiceServer) AccelPress(context.Context, *AccelPressRequest) (*empty.Empty, error)
func (*UnimplementedKeyboardServiceServer) AccelRelease ¶
func (*UnimplementedKeyboardServiceServer) AccelRelease(context.Context, *AccelReleaseRequest) (*empty.Empty, error)
func (*UnimplementedKeyboardServiceServer) Type ¶
func (*UnimplementedKeyboardServiceServer) Type(context.Context, *TypeRequest) (*empty.Empty, error)
type UnimplementedTouchpadServiceServer ¶
type UnimplementedTouchpadServiceServer struct {
}
UnimplementedTouchpadServiceServer can be embedded to have forward compatible implementations.
func (*UnimplementedTouchpadServiceServer) CloseChrome ¶
func (*UnimplementedTouchpadServiceServer) FindPhysicalTouchpad ¶
func (*UnimplementedTouchpadServiceServer) FindPhysicalTouchpad(context.Context, *empty.Empty) (*FindPhysicalTouchpadResponse, error)
func (*UnimplementedTouchpadServiceServer) TouchpadSwipe ¶
type UnimplementedTouchscreenServiceServer ¶
type UnimplementedTouchscreenServiceServer struct {
}
UnimplementedTouchscreenServiceServer can be embedded to have forward compatible implementations.
func (*UnimplementedTouchscreenServiceServer) CloseChrome ¶
func (*UnimplementedTouchscreenServiceServer) FindPhysicalTouchscreen ¶
func (*UnimplementedTouchscreenServiceServer) FindPhysicalTouchscreen(context.Context, *empty.Empty) (*FindPhysicalTouchscreenResponse, error)