Documentation
¶
Overview ¶
Package network provides protobuf interfaces for network related gRPC.
Index ¶
- Variables
- func RegisterAllowlistServiceServer(s *grpc.Server, srv AllowlistServiceServer)
- func RegisterBluetoothServiceServer(s *grpc.Server, srv BluetoothServiceServer)
- func RegisterNetDiagServiceServer(s *grpc.Server, srv NetDiagServiceServer)
- func RegisterProxyServiceServer(s *grpc.Server, srv ProxyServiceServer)
- type AllowlistServiceClient
- type AllowlistServiceServer
- type AuthCredentials
- func (*AuthCredentials) Descriptor() ([]byte, []int)deprecated
- func (x *AuthCredentials) GetPassword() string
- func (x *AuthCredentials) GetUsername() string
- func (*AuthCredentials) ProtoMessage()
- func (x *AuthCredentials) ProtoReflect() protoreflect.Message
- func (x *AuthCredentials) Reset()
- func (x *AuthCredentials) String() string
- type BluetoothServiceClient
- type BluetoothServiceServer
- type CheckArcAppInstalledRequest
- func (*CheckArcAppInstalledRequest) Descriptor() ([]byte, []int)deprecated
- func (x *CheckArcAppInstalledRequest) GetAppName() string
- func (*CheckArcAppInstalledRequest) ProtoMessage()
- func (x *CheckArcAppInstalledRequest) ProtoReflect() protoreflect.Message
- func (x *CheckArcAppInstalledRequest) Reset()
- func (x *CheckArcAppInstalledRequest) String() string
- type CheckExtensionInstalledRequest
- func (*CheckExtensionInstalledRequest) Descriptor() ([]byte, []int)deprecated
- func (x *CheckExtensionInstalledRequest) GetExtensionTitle() string
- func (*CheckExtensionInstalledRequest) ProtoMessage()
- func (x *CheckExtensionInstalledRequest) ProtoReflect() protoreflect.Message
- func (x *CheckExtensionInstalledRequest) Reset()
- func (x *CheckExtensionInstalledRequest) String() string
- type GaiaLoginRequest
- func (*GaiaLoginRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GaiaLoginRequest) GetPassword() string
- func (x *GaiaLoginRequest) GetProxyHostAndPort() string
- func (x *GaiaLoginRequest) GetUsername() string
- func (*GaiaLoginRequest) ProtoMessage()
- func (x *GaiaLoginRequest) ProtoReflect() protoreflect.Message
- func (x *GaiaLoginRequest) Reset()
- func (x *GaiaLoginRequest) String() string
- type GetBluetoothBootPrefRequest
- func (*GetBluetoothBootPrefRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetBluetoothBootPrefRequest) GetCredentials() string
- func (*GetBluetoothBootPrefRequest) ProtoMessage()
- func (x *GetBluetoothBootPrefRequest) ProtoReflect() protoreflect.Message
- func (x *GetBluetoothBootPrefRequest) Reset()
- func (x *GetBluetoothBootPrefRequest) String() string
- type GetBluetoothBootPrefResponse
- func (*GetBluetoothBootPrefResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetBluetoothBootPrefResponse) GetPersistent() bool
- func (*GetBluetoothBootPrefResponse) ProtoMessage()
- func (x *GetBluetoothBootPrefResponse) ProtoReflect() protoreflect.Message
- func (x *GetBluetoothBootPrefResponse) Reset()
- func (x *GetBluetoothBootPrefResponse) String() string
- type GetBluetoothPoweredFastResponse
- func (*GetBluetoothPoweredFastResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetBluetoothPoweredFastResponse) GetPowered() bool
- func (*GetBluetoothPoweredFastResponse) ProtoMessage()
- func (x *GetBluetoothPoweredFastResponse) ProtoReflect() protoreflect.Message
- func (x *GetBluetoothPoweredFastResponse) Reset()
- func (x *GetBluetoothPoweredFastResponse) String() string
- type NetDiagServiceClient
- type NetDiagServiceServer
- type ProxyServiceClient
- type ProxyServiceServer
- type RoutineResult
- func (*RoutineResult) Descriptor() ([]byte, []int)deprecated
- func (x *RoutineResult) GetProblems() []uint32
- func (x *RoutineResult) GetVerdict() int32
- func (*RoutineResult) ProtoMessage()
- func (x *RoutineResult) ProtoReflect() protoreflect.Message
- func (x *RoutineResult) Reset()
- func (x *RoutineResult) String() string
- type RunRoutineRequest
- type SetBluetoothPoweredFastRequest
- func (*SetBluetoothPoweredFastRequest) Descriptor() ([]byte, []int)deprecated
- func (x *SetBluetoothPoweredFastRequest) GetPowered() bool
- func (*SetBluetoothPoweredFastRequest) ProtoMessage()
- func (x *SetBluetoothPoweredFastRequest) ProtoReflect() protoreflect.Message
- func (x *SetBluetoothPoweredFastRequest) Reset()
- func (x *SetBluetoothPoweredFastRequest) String() string
- type SetBluetoothPoweredRequest
- func (*SetBluetoothPoweredRequest) Descriptor() ([]byte, []int)deprecated
- func (x *SetBluetoothPoweredRequest) GetCredentials() string
- func (x *SetBluetoothPoweredRequest) GetPowered() bool
- func (*SetBluetoothPoweredRequest) ProtoMessage()
- func (x *SetBluetoothPoweredRequest) ProtoReflect() protoreflect.Message
- func (x *SetBluetoothPoweredRequest) Reset()
- func (x *SetBluetoothPoweredRequest) String() string
- type SetupFirewallRequest
- func (*SetupFirewallRequest) Descriptor() ([]byte, []int)deprecated
- func (x *SetupFirewallRequest) GetAllowedPort() uint32
- func (*SetupFirewallRequest) ProtoMessage()
- func (x *SetupFirewallRequest) ProtoReflect() protoreflect.Message
- func (x *SetupFirewallRequest) Reset()
- func (x *SetupFirewallRequest) String() string
- type StartServerRequest
- func (*StartServerRequest) Descriptor() ([]byte, []int)deprecated
- func (x *StartServerRequest) GetAllowlist() []string
- func (x *StartServerRequest) GetAuthCredentials() *AuthCredentials
- func (x *StartServerRequest) GetPort() uint32
- func (*StartServerRequest) ProtoMessage()
- func (x *StartServerRequest) ProtoReflect() protoreflect.Message
- func (x *StartServerRequest) Reset()
- func (x *StartServerRequest) String() string
- type StartServerResponse
- func (*StartServerResponse) Descriptor() ([]byte, []int)deprecated
- func (x *StartServerResponse) GetHostAndPort() string
- func (*StartServerResponse) ProtoMessage()
- func (x *StartServerResponse) ProtoReflect() protoreflect.Message
- func (x *StartServerResponse) Reset()
- func (x *StartServerResponse) String() string
- type UnimplementedAllowlistServiceServer
- func (*UnimplementedAllowlistServiceServer) CheckArcAppInstalled(context.Context, *CheckArcAppInstalledRequest) (*empty.Empty, error)
- func (*UnimplementedAllowlistServiceServer) CheckExtensionInstalled(context.Context, *CheckExtensionInstalledRequest) (*empty.Empty, error)
- func (*UnimplementedAllowlistServiceServer) GaiaLogin(context.Context, *GaiaLoginRequest) (*empty.Empty, error)
- func (*UnimplementedAllowlistServiceServer) SetupFirewall(context.Context, *SetupFirewallRequest) (*empty.Empty, error)
- type UnimplementedBluetoothServiceServer
- func (*UnimplementedBluetoothServiceServer) GetBluetoothBootPref(context.Context, *GetBluetoothBootPrefRequest) (*GetBluetoothBootPrefResponse, error)
- func (*UnimplementedBluetoothServiceServer) GetBluetoothPoweredFast(context.Context, *empty.Empty) (*GetBluetoothPoweredFastResponse, error)
- func (*UnimplementedBluetoothServiceServer) SetBluetoothPowered(context.Context, *SetBluetoothPoweredRequest) (*empty.Empty, error)
- func (*UnimplementedBluetoothServiceServer) SetBluetoothPoweredFast(context.Context, *SetBluetoothPoweredFastRequest) (*empty.Empty, error)
- func (*UnimplementedBluetoothServiceServer) ValidateBluetoothFunctional(context.Context, *empty.Empty) (*empty.Empty, error)
- type UnimplementedNetDiagServiceServer
- func (*UnimplementedNetDiagServiceServer) Close(context.Context, *empty.Empty) (*empty.Empty, error)
- func (*UnimplementedNetDiagServiceServer) RunRoutine(context.Context, *RunRoutineRequest) (*RoutineResult, error)
- func (*UnimplementedNetDiagServiceServer) SetupDiagAPI(context.Context, *empty.Empty) (*empty.Empty, error)
- type UnimplementedProxyServiceServer
Constants ¶
This section is empty.
Variables ¶
var File_allowlist_service_proto protoreflect.FileDescriptor
var File_bluetooth_service_proto protoreflect.FileDescriptor
var File_diag_service_proto protoreflect.FileDescriptor
var File_proxy_service_proto protoreflect.FileDescriptor
Functions ¶
func RegisterAllowlistServiceServer ¶
func RegisterAllowlistServiceServer(s *grpc.Server, srv AllowlistServiceServer)
func RegisterBluetoothServiceServer ¶
func RegisterBluetoothServiceServer(s *grpc.Server, srv BluetoothServiceServer)
func RegisterNetDiagServiceServer ¶
func RegisterNetDiagServiceServer(s *grpc.Server, srv NetDiagServiceServer)
func RegisterProxyServiceServer ¶
func RegisterProxyServiceServer(s *grpc.Server, srv ProxyServiceServer)
Types ¶
type AllowlistServiceClient ¶
type AllowlistServiceClient interface {
// SetupFirewall sets up a firewall using `iptables`, blocking https and https
// connections through the default ports (80,443). Only http/s connections
// coming from a specified port are allowed.
SetupFirewall(ctx context.Context, in *SetupFirewallRequest, opts ...grpc.CallOption) (*empty.Empty, error)
// GaiaLogin starts a new Chrome instance behind a proxy and performs
// Chrome OS login using the specified credentials.
GaiaLogin(ctx context.Context, in *GaiaLoginRequest, opts ...grpc.CallOption) (*empty.Empty, error)
// CheckArcAppInstalled verifies that a specified ARC app is installed.
CheckArcAppInstalled(ctx context.Context, in *CheckArcAppInstalledRequest, opts ...grpc.CallOption) (*empty.Empty, error)
// CheckExtensionInstalled verifies that specified extension is installed.
CheckExtensionInstalled(ctx context.Context, in *CheckExtensionInstalledRequest, opts ...grpc.CallOption) (*empty.Empty, error)
}
AllowlistServiceClient is the client API for AllowlistService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
func NewAllowlistServiceClient ¶
func NewAllowlistServiceClient(cc grpc.ClientConnInterface) AllowlistServiceClient
type AllowlistServiceServer ¶
type AllowlistServiceServer interface {
// SetupFirewall sets up a firewall using `iptables`, blocking https and https
// connections through the default ports (80,443). Only http/s connections
// coming from a specified port are allowed.
SetupFirewall(context.Context, *SetupFirewallRequest) (*empty.Empty, error)
// GaiaLogin starts a new Chrome instance behind a proxy and performs
// Chrome OS login using the specified credentials.
GaiaLogin(context.Context, *GaiaLoginRequest) (*empty.Empty, error)
// CheckArcAppInstalled verifies that a specified ARC app is installed.
CheckArcAppInstalled(context.Context, *CheckArcAppInstalledRequest) (*empty.Empty, error)
// CheckExtensionInstalled verifies that specified extension is installed.
CheckExtensionInstalled(context.Context, *CheckExtensionInstalledRequest) (*empty.Empty, error)
}
AllowlistServiceServer is the server API for AllowlistService service.
type AuthCredentials ¶
type AuthCredentials struct {
Username string `protobuf:"bytes,1,opt,name=username,proto3" json:"username,omitempty"`
Password string `protobuf:"bytes,2,opt,name=password,proto3" json:"password,omitempty"`
// contains filtered or unexported fields
}
func (*AuthCredentials) Descriptor
deprecated
func (*AuthCredentials) Descriptor() ([]byte, []int)
Deprecated: Use AuthCredentials.ProtoReflect.Descriptor instead.
func (*AuthCredentials) GetPassword ¶
func (x *AuthCredentials) GetPassword() string
func (*AuthCredentials) GetUsername ¶
func (x *AuthCredentials) GetUsername() string
func (*AuthCredentials) ProtoMessage ¶
func (*AuthCredentials) ProtoMessage()
func (*AuthCredentials) ProtoReflect ¶
func (x *AuthCredentials) ProtoReflect() protoreflect.Message
func (*AuthCredentials) Reset ¶
func (x *AuthCredentials) Reset()
func (*AuthCredentials) String ¶
func (x *AuthCredentials) String() string
type BluetoothServiceClient ¶
type BluetoothServiceClient interface {
// SetBluetoothPowered sets the Bluetooth adapter power status via settingsPrivate. This setting persists across reboots.
SetBluetoothPowered(ctx context.Context, in *SetBluetoothPoweredRequest, opts ...grpc.CallOption) (*empty.Empty, error)
// SetBluetoothPoweredFast sets the Bluetooth adapter power status via D-Bus. This setting does not persist across boots.
SetBluetoothPoweredFast(ctx context.Context, in *SetBluetoothPoweredFastRequest, opts ...grpc.CallOption) (*empty.Empty, error)
// GetBluetoothBootPref gets the Bluetooth boot preference.
GetBluetoothBootPref(ctx context.Context, in *GetBluetoothBootPrefRequest, opts ...grpc.CallOption) (*GetBluetoothBootPrefResponse, error)
// GetBluetoothPoweredFast checks whether the Bluetooth adapter is enabled.
GetBluetoothPoweredFast(ctx context.Context, in *empty.Empty, opts ...grpc.CallOption) (*GetBluetoothPoweredFastResponse, error)
// ValidateBluetoothFunctional checks to see whether the Bluetooth device is usable.
ValidateBluetoothFunctional(ctx context.Context, in *empty.Empty, opts ...grpc.CallOption) (*empty.Empty, error)
}
BluetoothServiceClient is the client API for BluetoothService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
func NewBluetoothServiceClient ¶
func NewBluetoothServiceClient(cc grpc.ClientConnInterface) BluetoothServiceClient
type BluetoothServiceServer ¶
type BluetoothServiceServer interface {
// SetBluetoothPowered sets the Bluetooth adapter power status via settingsPrivate. This setting persists across reboots.
SetBluetoothPowered(context.Context, *SetBluetoothPoweredRequest) (*empty.Empty, error)
// SetBluetoothPoweredFast sets the Bluetooth adapter power status via D-Bus. This setting does not persist across boots.
SetBluetoothPoweredFast(context.Context, *SetBluetoothPoweredFastRequest) (*empty.Empty, error)
// GetBluetoothBootPref gets the Bluetooth boot preference.
GetBluetoothBootPref(context.Context, *GetBluetoothBootPrefRequest) (*GetBluetoothBootPrefResponse, error)
// GetBluetoothPoweredFast checks whether the Bluetooth adapter is enabled.
GetBluetoothPoweredFast(context.Context, *empty.Empty) (*GetBluetoothPoweredFastResponse, error)
// ValidateBluetoothFunctional checks to see whether the Bluetooth device is usable.
ValidateBluetoothFunctional(context.Context, *empty.Empty) (*empty.Empty, error)
}
BluetoothServiceServer is the server API for BluetoothService service.
type CheckArcAppInstalledRequest ¶
type CheckArcAppInstalledRequest struct {
AppName string `protobuf:"bytes,1,opt,name=app_name,json=appName,proto3" json:"app_name,omitempty"`
// contains filtered or unexported fields
}
func (*CheckArcAppInstalledRequest) Descriptor
deprecated
func (*CheckArcAppInstalledRequest) Descriptor() ([]byte, []int)
Deprecated: Use CheckArcAppInstalledRequest.ProtoReflect.Descriptor instead.
func (*CheckArcAppInstalledRequest) GetAppName ¶
func (x *CheckArcAppInstalledRequest) GetAppName() string
func (*CheckArcAppInstalledRequest) ProtoMessage ¶
func (*CheckArcAppInstalledRequest) ProtoMessage()
func (*CheckArcAppInstalledRequest) ProtoReflect ¶
func (x *CheckArcAppInstalledRequest) ProtoReflect() protoreflect.Message
func (*CheckArcAppInstalledRequest) Reset ¶
func (x *CheckArcAppInstalledRequest) Reset()
func (*CheckArcAppInstalledRequest) String ¶
func (x *CheckArcAppInstalledRequest) String() string
type CheckExtensionInstalledRequest ¶
type CheckExtensionInstalledRequest struct {
ExtensionTitle string `protobuf:"bytes,1,opt,name=extension_title,json=extensionTitle,proto3" json:"extension_title,omitempty"`
// contains filtered or unexported fields
}
func (*CheckExtensionInstalledRequest) Descriptor
deprecated
func (*CheckExtensionInstalledRequest) Descriptor() ([]byte, []int)
Deprecated: Use CheckExtensionInstalledRequest.ProtoReflect.Descriptor instead.
func (*CheckExtensionInstalledRequest) GetExtensionTitle ¶
func (x *CheckExtensionInstalledRequest) GetExtensionTitle() string
func (*CheckExtensionInstalledRequest) ProtoMessage ¶
func (*CheckExtensionInstalledRequest) ProtoMessage()
func (*CheckExtensionInstalledRequest) ProtoReflect ¶
func (x *CheckExtensionInstalledRequest) ProtoReflect() protoreflect.Message
func (*CheckExtensionInstalledRequest) Reset ¶
func (x *CheckExtensionInstalledRequest) Reset()
func (*CheckExtensionInstalledRequest) String ¶
func (x *CheckExtensionInstalledRequest) String() string
type GaiaLoginRequest ¶
type GaiaLoginRequest struct {
Username string `protobuf:"bytes,1,opt,name=username,proto3" json:"username,omitempty"`
Password string `protobuf:"bytes,2,opt,name=password,proto3" json:"password,omitempty"`
// Host and port of an HTTP proxy, formatted as "<host>:<port>". The new
// instance of Chrome will point to the proxy via command line args.
ProxyHostAndPort string `protobuf:"bytes,3,opt,name=proxy_host_and_port,json=proxyHostAndPort,proto3" json:"proxy_host_and_port,omitempty"`
// contains filtered or unexported fields
}
func (*GaiaLoginRequest) Descriptor
deprecated
func (*GaiaLoginRequest) Descriptor() ([]byte, []int)
Deprecated: Use GaiaLoginRequest.ProtoReflect.Descriptor instead.
func (*GaiaLoginRequest) GetPassword ¶
func (x *GaiaLoginRequest) GetPassword() string
func (*GaiaLoginRequest) GetProxyHostAndPort ¶
func (x *GaiaLoginRequest) GetProxyHostAndPort() string
func (*GaiaLoginRequest) GetUsername ¶
func (x *GaiaLoginRequest) GetUsername() string
func (*GaiaLoginRequest) ProtoMessage ¶
func (*GaiaLoginRequest) ProtoMessage()
func (*GaiaLoginRequest) ProtoReflect ¶
func (x *GaiaLoginRequest) ProtoReflect() protoreflect.Message
func (*GaiaLoginRequest) Reset ¶
func (x *GaiaLoginRequest) Reset()
func (*GaiaLoginRequest) String ¶
func (x *GaiaLoginRequest) String() string
type GetBluetoothBootPrefRequest ¶
type GetBluetoothBootPrefRequest struct {
Credentials string `protobuf:"bytes,1,opt,name=credentials,proto3" json:"credentials,omitempty"`
// contains filtered or unexported fields
}
func (*GetBluetoothBootPrefRequest) Descriptor
deprecated
func (*GetBluetoothBootPrefRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetBluetoothBootPrefRequest.ProtoReflect.Descriptor instead.
func (*GetBluetoothBootPrefRequest) GetCredentials ¶
func (x *GetBluetoothBootPrefRequest) GetCredentials() string
func (*GetBluetoothBootPrefRequest) ProtoMessage ¶
func (*GetBluetoothBootPrefRequest) ProtoMessage()
func (*GetBluetoothBootPrefRequest) ProtoReflect ¶
func (x *GetBluetoothBootPrefRequest) ProtoReflect() protoreflect.Message
func (*GetBluetoothBootPrefRequest) Reset ¶
func (x *GetBluetoothBootPrefRequest) Reset()
func (*GetBluetoothBootPrefRequest) String ¶
func (x *GetBluetoothBootPrefRequest) String() string
type GetBluetoothBootPrefResponse ¶
type GetBluetoothBootPrefResponse struct {
Persistent bool `protobuf:"varint,1,opt,name=persistent,proto3" json:"persistent,omitempty"`
// contains filtered or unexported fields
}
func (*GetBluetoothBootPrefResponse) Descriptor
deprecated
func (*GetBluetoothBootPrefResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetBluetoothBootPrefResponse.ProtoReflect.Descriptor instead.
func (*GetBluetoothBootPrefResponse) GetPersistent ¶
func (x *GetBluetoothBootPrefResponse) GetPersistent() bool
func (*GetBluetoothBootPrefResponse) ProtoMessage ¶
func (*GetBluetoothBootPrefResponse) ProtoMessage()
func (*GetBluetoothBootPrefResponse) ProtoReflect ¶
func (x *GetBluetoothBootPrefResponse) ProtoReflect() protoreflect.Message
func (*GetBluetoothBootPrefResponse) Reset ¶
func (x *GetBluetoothBootPrefResponse) Reset()
func (*GetBluetoothBootPrefResponse) String ¶
func (x *GetBluetoothBootPrefResponse) String() string
type GetBluetoothPoweredFastResponse ¶
type GetBluetoothPoweredFastResponse struct {
Powered bool `protobuf:"varint,1,opt,name=powered,proto3" json:"powered,omitempty"`
// contains filtered or unexported fields
}
func (*GetBluetoothPoweredFastResponse) Descriptor
deprecated
func (*GetBluetoothPoweredFastResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetBluetoothPoweredFastResponse.ProtoReflect.Descriptor instead.
func (*GetBluetoothPoweredFastResponse) GetPowered ¶
func (x *GetBluetoothPoweredFastResponse) GetPowered() bool
func (*GetBluetoothPoweredFastResponse) ProtoMessage ¶
func (*GetBluetoothPoweredFastResponse) ProtoMessage()
func (*GetBluetoothPoweredFastResponse) ProtoReflect ¶
func (x *GetBluetoothPoweredFastResponse) ProtoReflect() protoreflect.Message
func (*GetBluetoothPoweredFastResponse) Reset ¶
func (x *GetBluetoothPoweredFastResponse) Reset()
func (*GetBluetoothPoweredFastResponse) String ¶
func (x *GetBluetoothPoweredFastResponse) String() string
type NetDiagServiceClient ¶
type NetDiagServiceClient interface {
// SetupDiagAPI creates a new chrome instance and launches the connectivity
// diagnostics application to be used for running the network diagnostics.
SetupDiagAPI(ctx context.Context, in *empty.Empty, opts ...grpc.CallOption) (*empty.Empty, error)
// Close will close the connectivity diagnostics application and the
// underlying Chrome instance.
Close(ctx context.Context, in *empty.Empty, opts ...grpc.CallOption) (*empty.Empty, error)
// RunRoutine will run the specified network diagnostic routine and return the
// result.
RunRoutine(ctx context.Context, in *RunRoutineRequest, opts ...grpc.CallOption) (*RoutineResult, error)
}
NetDiagServiceClient is the client API for NetDiagService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
func NewNetDiagServiceClient ¶
func NewNetDiagServiceClient(cc grpc.ClientConnInterface) NetDiagServiceClient
type NetDiagServiceServer ¶
type NetDiagServiceServer interface {
// SetupDiagAPI creates a new chrome instance and launches the connectivity
// diagnostics application to be used for running the network diagnostics.
SetupDiagAPI(context.Context, *empty.Empty) (*empty.Empty, error)
// Close will close the connectivity diagnostics application and the
// underlying Chrome instance.
Close(context.Context, *empty.Empty) (*empty.Empty, error)
// RunRoutine will run the specified network diagnostic routine and return the
// result.
RunRoutine(context.Context, *RunRoutineRequest) (*RoutineResult, error)
}
NetDiagServiceServer is the server API for NetDiagService service.
type ProxyServiceClient ¶
type ProxyServiceClient interface {
// StartServer starts a proxy server instance with the given configuration.
StartServer(ctx context.Context, in *StartServerRequest, opts ...grpc.CallOption) (*StartServerResponse, error)
// StopServer stops the running server instance.
StopServer(ctx context.Context, in *empty.Empty, opts ...grpc.CallOption) (*empty.Empty, error)
}
ProxyServiceClient is the client API for ProxyService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
func NewProxyServiceClient ¶
func NewProxyServiceClient(cc grpc.ClientConnInterface) ProxyServiceClient
type ProxyServiceServer ¶
type ProxyServiceServer interface {
// StartServer starts a proxy server instance with the given configuration.
StartServer(context.Context, *StartServerRequest) (*StartServerResponse, error)
// StopServer stops the running server instance.
StopServer(context.Context, *empty.Empty) (*empty.Empty, error)
}
ProxyServiceServer is the server API for ProxyService service.
type RoutineResult ¶
type RoutineResult struct {
// The verdict of running the routine.
Verdict int32 `protobuf:"varint,1,opt,name=verdict,proto3" json:"verdict,omitempty"`
// List of routine problems if they exist.
Problems []uint32 `protobuf:"varint,2,rep,packed,name=problems,proto3" json:"problems,omitempty"`
// contains filtered or unexported fields
}
func (*RoutineResult) Descriptor
deprecated
func (*RoutineResult) Descriptor() ([]byte, []int)
Deprecated: Use RoutineResult.ProtoReflect.Descriptor instead.
func (*RoutineResult) GetProblems ¶
func (x *RoutineResult) GetProblems() []uint32
func (*RoutineResult) GetVerdict ¶
func (x *RoutineResult) GetVerdict() int32
func (*RoutineResult) ProtoMessage ¶
func (*RoutineResult) ProtoMessage()
func (*RoutineResult) ProtoReflect ¶
func (x *RoutineResult) ProtoReflect() protoreflect.Message
func (*RoutineResult) Reset ¶
func (x *RoutineResult) Reset()
func (*RoutineResult) String ¶
func (x *RoutineResult) String() string
type RunRoutineRequest ¶
type RunRoutineRequest struct {
// The name of the routine to run.
Routine string `protobuf:"bytes,1,opt,name=routine,proto3" json:"routine,omitempty"`
// contains filtered or unexported fields
}
func (*RunRoutineRequest) Descriptor
deprecated
func (*RunRoutineRequest) Descriptor() ([]byte, []int)
Deprecated: Use RunRoutineRequest.ProtoReflect.Descriptor instead.
func (*RunRoutineRequest) GetRoutine ¶
func (x *RunRoutineRequest) GetRoutine() string
func (*RunRoutineRequest) ProtoMessage ¶
func (*RunRoutineRequest) ProtoMessage()
func (*RunRoutineRequest) ProtoReflect ¶
func (x *RunRoutineRequest) ProtoReflect() protoreflect.Message
func (*RunRoutineRequest) Reset ¶
func (x *RunRoutineRequest) Reset()
func (*RunRoutineRequest) String ¶
func (x *RunRoutineRequest) String() string
type SetBluetoothPoweredFastRequest ¶
type SetBluetoothPoweredFastRequest struct {
Powered bool `protobuf:"varint,1,opt,name=powered,proto3" json:"powered,omitempty"`
// contains filtered or unexported fields
}
func (*SetBluetoothPoweredFastRequest) Descriptor
deprecated
func (*SetBluetoothPoweredFastRequest) Descriptor() ([]byte, []int)
Deprecated: Use SetBluetoothPoweredFastRequest.ProtoReflect.Descriptor instead.
func (*SetBluetoothPoweredFastRequest) GetPowered ¶
func (x *SetBluetoothPoweredFastRequest) GetPowered() bool
func (*SetBluetoothPoweredFastRequest) ProtoMessage ¶
func (*SetBluetoothPoweredFastRequest) ProtoMessage()
func (*SetBluetoothPoweredFastRequest) ProtoReflect ¶
func (x *SetBluetoothPoweredFastRequest) ProtoReflect() protoreflect.Message
func (*SetBluetoothPoweredFastRequest) Reset ¶
func (x *SetBluetoothPoweredFastRequest) Reset()
func (*SetBluetoothPoweredFastRequest) String ¶
func (x *SetBluetoothPoweredFastRequest) String() string
type SetBluetoothPoweredRequest ¶
type SetBluetoothPoweredRequest struct {
Powered bool `protobuf:"varint,1,opt,name=powered,proto3" json:"powered,omitempty"`
Credentials string `protobuf:"bytes,2,opt,name=credentials,proto3" json:"credentials,omitempty"`
// contains filtered or unexported fields
}
func (*SetBluetoothPoweredRequest) Descriptor
deprecated
func (*SetBluetoothPoweredRequest) Descriptor() ([]byte, []int)
Deprecated: Use SetBluetoothPoweredRequest.ProtoReflect.Descriptor instead.
func (*SetBluetoothPoweredRequest) GetCredentials ¶
func (x *SetBluetoothPoweredRequest) GetCredentials() string
func (*SetBluetoothPoweredRequest) GetPowered ¶
func (x *SetBluetoothPoweredRequest) GetPowered() bool
func (*SetBluetoothPoweredRequest) ProtoMessage ¶
func (*SetBluetoothPoweredRequest) ProtoMessage()
func (*SetBluetoothPoweredRequest) ProtoReflect ¶
func (x *SetBluetoothPoweredRequest) ProtoReflect() protoreflect.Message
func (*SetBluetoothPoweredRequest) Reset ¶
func (x *SetBluetoothPoweredRequest) Reset()
func (*SetBluetoothPoweredRequest) String ¶
func (x *SetBluetoothPoweredRequest) String() string
type SetupFirewallRequest ¶
type SetupFirewallRequest struct {
// Must be a valid port number. Only http/s connection from this port are
// allowed by the firewall.
AllowedPort uint32 `protobuf:"varint,1,opt,name=allowed_port,json=allowedPort,proto3" json:"allowed_port,omitempty"`
// contains filtered or unexported fields
}
func (*SetupFirewallRequest) Descriptor
deprecated
func (*SetupFirewallRequest) Descriptor() ([]byte, []int)
Deprecated: Use SetupFirewallRequest.ProtoReflect.Descriptor instead.
func (*SetupFirewallRequest) GetAllowedPort ¶
func (x *SetupFirewallRequest) GetAllowedPort() uint32
func (*SetupFirewallRequest) ProtoMessage ¶
func (*SetupFirewallRequest) ProtoMessage()
func (*SetupFirewallRequest) ProtoReflect ¶
func (x *SetupFirewallRequest) ProtoReflect() protoreflect.Message
func (*SetupFirewallRequest) Reset ¶
func (x *SetupFirewallRequest) Reset()
func (*SetupFirewallRequest) String ¶
func (x *SetupFirewallRequest) String() string
type StartServerRequest ¶
type StartServerRequest struct {
// Optional. Port where the proxy should listen for incoming connections. Must
// be a valid port value (1 to 65535). If not set, the default value is 3128.
Port uint32 `protobuf:"varint,1,opt,name=port,proto3" json:"port,omitempty"`
// Credentials for basic authentication. If set, clients connecting to the
// proxy server must provide the same credentials for authentication otherwise
// the connection will fail. Leave unset if the proxy should not require
// authentication.
AuthCredentials *AuthCredentials `protobuf:"bytes,2,opt,name=auth_credentials,json=authCredentials,proto3" json:"auth_credentials,omitempty"`
// Specifies the hostnames to which connections are allowed through the proxy.
// Regex expressions and IP addresses are allowed.
Allowlist []string `protobuf:"bytes,3,rep,name=allowlist,proto3" json:"allowlist,omitempty"`
// contains filtered or unexported fields
}
func (*StartServerRequest) Descriptor
deprecated
func (*StartServerRequest) Descriptor() ([]byte, []int)
Deprecated: Use StartServerRequest.ProtoReflect.Descriptor instead.
func (*StartServerRequest) GetAllowlist ¶
func (x *StartServerRequest) GetAllowlist() []string
func (*StartServerRequest) GetAuthCredentials ¶
func (x *StartServerRequest) GetAuthCredentials() *AuthCredentials
func (*StartServerRequest) GetPort ¶
func (x *StartServerRequest) GetPort() uint32
func (*StartServerRequest) ProtoMessage ¶
func (*StartServerRequest) ProtoMessage()
func (*StartServerRequest) ProtoReflect ¶
func (x *StartServerRequest) ProtoReflect() protoreflect.Message
func (*StartServerRequest) Reset ¶
func (x *StartServerRequest) Reset()
func (*StartServerRequest) String ¶
func (x *StartServerRequest) String() string
type StartServerResponse ¶
type StartServerResponse struct {
// The host and port where the proxy is listening for connections, in the
// format <host>:<port>. Clients should use this value to point to the proxy
// server. NOTE: This is an HTTP proxy.
HostAndPort string `protobuf:"bytes,1,opt,name=host_and_port,json=hostAndPort,proto3" json:"host_and_port,omitempty"`
// contains filtered or unexported fields
}
func (*StartServerResponse) Descriptor
deprecated
func (*StartServerResponse) Descriptor() ([]byte, []int)
Deprecated: Use StartServerResponse.ProtoReflect.Descriptor instead.
func (*StartServerResponse) GetHostAndPort ¶
func (x *StartServerResponse) GetHostAndPort() string
func (*StartServerResponse) ProtoMessage ¶
func (*StartServerResponse) ProtoMessage()
func (*StartServerResponse) ProtoReflect ¶
func (x *StartServerResponse) ProtoReflect() protoreflect.Message
func (*StartServerResponse) Reset ¶
func (x *StartServerResponse) Reset()
func (*StartServerResponse) String ¶
func (x *StartServerResponse) String() string
type UnimplementedAllowlistServiceServer ¶
type UnimplementedAllowlistServiceServer struct {
}
UnimplementedAllowlistServiceServer can be embedded to have forward compatible implementations.
func (*UnimplementedAllowlistServiceServer) CheckArcAppInstalled ¶
func (*UnimplementedAllowlistServiceServer) CheckArcAppInstalled(context.Context, *CheckArcAppInstalledRequest) (*empty.Empty, error)
func (*UnimplementedAllowlistServiceServer) CheckExtensionInstalled ¶
func (*UnimplementedAllowlistServiceServer) CheckExtensionInstalled(context.Context, *CheckExtensionInstalledRequest) (*empty.Empty, error)
func (*UnimplementedAllowlistServiceServer) GaiaLogin ¶
func (*UnimplementedAllowlistServiceServer) GaiaLogin(context.Context, *GaiaLoginRequest) (*empty.Empty, error)
func (*UnimplementedAllowlistServiceServer) SetupFirewall ¶
func (*UnimplementedAllowlistServiceServer) SetupFirewall(context.Context, *SetupFirewallRequest) (*empty.Empty, error)
type UnimplementedBluetoothServiceServer ¶
type UnimplementedBluetoothServiceServer struct {
}
UnimplementedBluetoothServiceServer can be embedded to have forward compatible implementations.
func (*UnimplementedBluetoothServiceServer) GetBluetoothBootPref ¶
func (*UnimplementedBluetoothServiceServer) GetBluetoothBootPref(context.Context, *GetBluetoothBootPrefRequest) (*GetBluetoothBootPrefResponse, error)
func (*UnimplementedBluetoothServiceServer) GetBluetoothPoweredFast ¶
func (*UnimplementedBluetoothServiceServer) GetBluetoothPoweredFast(context.Context, *empty.Empty) (*GetBluetoothPoweredFastResponse, error)
func (*UnimplementedBluetoothServiceServer) SetBluetoothPowered ¶
func (*UnimplementedBluetoothServiceServer) SetBluetoothPowered(context.Context, *SetBluetoothPoweredRequest) (*empty.Empty, error)
func (*UnimplementedBluetoothServiceServer) SetBluetoothPoweredFast ¶
func (*UnimplementedBluetoothServiceServer) SetBluetoothPoweredFast(context.Context, *SetBluetoothPoweredFastRequest) (*empty.Empty, error)
func (*UnimplementedBluetoothServiceServer) ValidateBluetoothFunctional ¶
type UnimplementedNetDiagServiceServer ¶
type UnimplementedNetDiagServiceServer struct {
}
UnimplementedNetDiagServiceServer can be embedded to have forward compatible implementations.
func (*UnimplementedNetDiagServiceServer) RunRoutine ¶
func (*UnimplementedNetDiagServiceServer) RunRoutine(context.Context, *RunRoutineRequest) (*RoutineResult, error)
func (*UnimplementedNetDiagServiceServer) SetupDiagAPI ¶
type UnimplementedProxyServiceServer ¶
type UnimplementedProxyServiceServer struct {
}
UnimplementedProxyServiceServer can be embedded to have forward compatible implementations.
func (*UnimplementedProxyServiceServer) StartServer ¶
func (*UnimplementedProxyServiceServer) StartServer(context.Context, *StartServerRequest) (*StartServerResponse, error)