Documentation
¶
Overview ¶
Package security contains Tast test services that exercise core security-related features.
Some of these tests could arguably live elsewhere (e.g. the kernel or platform packages), but we group them here based on their relevance to security.
Index ¶
- Variables
- func RegisterBootLockboxServiceServer(s *grpc.Server, srv BootLockboxServiceServer)
- type BootLockboxServiceClient
- type BootLockboxServiceServer
- type ReadBootLockboxRequest
- func (*ReadBootLockboxRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ReadBootLockboxRequest) GetKey() string
- func (*ReadBootLockboxRequest) ProtoMessage()
- func (x *ReadBootLockboxRequest) ProtoReflect() protoreflect.Message
- func (x *ReadBootLockboxRequest) Reset()
- func (x *ReadBootLockboxRequest) String() string
- type ReadBootLockboxResponse
- func (*ReadBootLockboxResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ReadBootLockboxResponse) GetValue() []byte
- func (*ReadBootLockboxResponse) ProtoMessage()
- func (x *ReadBootLockboxResponse) ProtoReflect() protoreflect.Message
- func (x *ReadBootLockboxResponse) Reset()
- func (x *ReadBootLockboxResponse) String() string
- type StoreBootLockboxRequest
- func (*StoreBootLockboxRequest) Descriptor() ([]byte, []int)deprecated
- func (x *StoreBootLockboxRequest) GetKey() string
- func (x *StoreBootLockboxRequest) GetValue() []byte
- func (*StoreBootLockboxRequest) ProtoMessage()
- func (x *StoreBootLockboxRequest) ProtoReflect() protoreflect.Message
- func (x *StoreBootLockboxRequest) Reset()
- func (x *StoreBootLockboxRequest) String() string
- type UnimplementedBootLockboxServiceServer
- func (*UnimplementedBootLockboxServiceServer) CloseChrome(context.Context, *empty.Empty) (*empty.Empty, error)
- func (*UnimplementedBootLockboxServiceServer) NewChromeLogin(context.Context, *empty.Empty) (*empty.Empty, error)
- func (*UnimplementedBootLockboxServiceServer) Read(context.Context, *ReadBootLockboxRequest) (*ReadBootLockboxResponse, error)
- func (*UnimplementedBootLockboxServiceServer) Store(context.Context, *StoreBootLockboxRequest) (*empty.Empty, error)
Constants ¶
This section is empty.
Variables ¶
var File_boot_lockbox_service_proto protoreflect.FileDescriptor
Functions ¶
func RegisterBootLockboxServiceServer ¶
func RegisterBootLockboxServiceServer(s *grpc.Server, srv BootLockboxServiceServer)
Types ¶
type BootLockboxServiceClient ¶
type BootLockboxServiceClient interface {
// New logs into a Chrome session as a fake user. Close must be called later
// to clean up the associated resources.
NewChromeLogin(ctx context.Context, in *empty.Empty, opts ...grpc.CallOption) (*empty.Empty, error)
// Close releases the resources obtained by New.
CloseChrome(ctx context.Context, in *empty.Empty, opts ...grpc.CallOption) (*empty.Empty, error)
// Reads a value from Boot Lockbox.
Read(ctx context.Context, in *ReadBootLockboxRequest, opts ...grpc.CallOption) (*ReadBootLockboxResponse, error)
// Stores a value to Boot Lockbox.
Store(ctx context.Context, in *StoreBootLockboxRequest, opts ...grpc.CallOption) (*empty.Empty, error)
}
BootLockboxServiceClient is the client API for BootLockboxService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
func NewBootLockboxServiceClient ¶
func NewBootLockboxServiceClient(cc grpc.ClientConnInterface) BootLockboxServiceClient
type BootLockboxServiceServer ¶
type BootLockboxServiceServer interface {
// New logs into a Chrome session as a fake user. Close must be called later
// to clean up the associated resources.
NewChromeLogin(context.Context, *empty.Empty) (*empty.Empty, error)
// Close releases the resources obtained by New.
CloseChrome(context.Context, *empty.Empty) (*empty.Empty, error)
// Reads a value from Boot Lockbox.
Read(context.Context, *ReadBootLockboxRequest) (*ReadBootLockboxResponse, error)
// Stores a value to Boot Lockbox.
Store(context.Context, *StoreBootLockboxRequest) (*empty.Empty, error)
}
BootLockboxServiceServer is the server API for BootLockboxService service.
type ReadBootLockboxRequest ¶
type ReadBootLockboxRequest struct {
Key string `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
// contains filtered or unexported fields
}
func (*ReadBootLockboxRequest) Descriptor
deprecated
func (*ReadBootLockboxRequest) Descriptor() ([]byte, []int)
Deprecated: Use ReadBootLockboxRequest.ProtoReflect.Descriptor instead.
func (*ReadBootLockboxRequest) GetKey ¶
func (x *ReadBootLockboxRequest) GetKey() string
func (*ReadBootLockboxRequest) ProtoMessage ¶
func (*ReadBootLockboxRequest) ProtoMessage()
func (*ReadBootLockboxRequest) ProtoReflect ¶
func (x *ReadBootLockboxRequest) ProtoReflect() protoreflect.Message
func (*ReadBootLockboxRequest) Reset ¶
func (x *ReadBootLockboxRequest) Reset()
func (*ReadBootLockboxRequest) String ¶
func (x *ReadBootLockboxRequest) String() string
type ReadBootLockboxResponse ¶
type ReadBootLockboxResponse struct {
Value []byte `protobuf:"bytes,1,opt,name=value,proto3" json:"value,omitempty"`
// contains filtered or unexported fields
}
func (*ReadBootLockboxResponse) Descriptor
deprecated
func (*ReadBootLockboxResponse) Descriptor() ([]byte, []int)
Deprecated: Use ReadBootLockboxResponse.ProtoReflect.Descriptor instead.
func (*ReadBootLockboxResponse) GetValue ¶
func (x *ReadBootLockboxResponse) GetValue() []byte
func (*ReadBootLockboxResponse) ProtoMessage ¶
func (*ReadBootLockboxResponse) ProtoMessage()
func (*ReadBootLockboxResponse) ProtoReflect ¶
func (x *ReadBootLockboxResponse) ProtoReflect() protoreflect.Message
func (*ReadBootLockboxResponse) Reset ¶
func (x *ReadBootLockboxResponse) Reset()
func (*ReadBootLockboxResponse) String ¶
func (x *ReadBootLockboxResponse) String() string
type StoreBootLockboxRequest ¶
type StoreBootLockboxRequest struct {
Key string `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
Value []byte `protobuf:"bytes,2,opt,name=value,proto3" json:"value,omitempty"`
// contains filtered or unexported fields
}
func (*StoreBootLockboxRequest) Descriptor
deprecated
func (*StoreBootLockboxRequest) Descriptor() ([]byte, []int)
Deprecated: Use StoreBootLockboxRequest.ProtoReflect.Descriptor instead.
func (*StoreBootLockboxRequest) GetKey ¶
func (x *StoreBootLockboxRequest) GetKey() string
func (*StoreBootLockboxRequest) GetValue ¶
func (x *StoreBootLockboxRequest) GetValue() []byte
func (*StoreBootLockboxRequest) ProtoMessage ¶
func (*StoreBootLockboxRequest) ProtoMessage()
func (*StoreBootLockboxRequest) ProtoReflect ¶
func (x *StoreBootLockboxRequest) ProtoReflect() protoreflect.Message
func (*StoreBootLockboxRequest) Reset ¶
func (x *StoreBootLockboxRequest) Reset()
func (*StoreBootLockboxRequest) String ¶
func (x *StoreBootLockboxRequest) String() string
type UnimplementedBootLockboxServiceServer ¶
type UnimplementedBootLockboxServiceServer struct {
}
UnimplementedBootLockboxServiceServer can be embedded to have forward compatible implementations.
func (*UnimplementedBootLockboxServiceServer) CloseChrome ¶
func (*UnimplementedBootLockboxServiceServer) NewChromeLogin ¶
func (*UnimplementedBootLockboxServiceServer) Store ¶
func (*UnimplementedBootLockboxServiceServer) Store(context.Context, *StoreBootLockboxRequest) (*empty.Empty, error)