Documentation
¶
Overview ¶
Package legacyjson defines the schema of JSON-based representation of tests used only for -dumptests option in test bundles.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type EntityInfo ¶
type EntityInfo struct {
// See TestInstance for details of the fields.
Name string `json:"name"`
Pkg string `json:"pkg"`
Desc string `json:"desc"`
Contacts []string `json:"contacts"`
Attr []string `json:"attr"`
Data []string `json:"data"`
Vars []string `json:"vars,omitempty"`
VarDeps []string `json:"varDeps,omitempty"`
SoftwareDeps dep.SoftwareDeps `json:"softwareDeps,omitempty"`
ServiceDeps []string `json:"serviceDeps,omitempty"`
Fixture string `json:"fixture,omitempty"`
Timeout time.Duration `json:"timeout"`
// Bundle is the basename of the executable containing the entity.
// Symlinks are not evaluated.
Bundle string `json:"bundle,omitempty"`
}
EntityInfo is a JSON-serializable description of an entity.
func EntityInfoFromProto ¶
func EntityInfoFromProto(e *protocol.Entity) (*EntityInfo, error)
EntityInfoFromProto converts protocol.Entity to jsonprotocol.EntityInfo.
func MustEntityInfoFromProto ¶
func MustEntityInfoFromProto(e *protocol.Entity) *EntityInfo
MustEntityInfoFromProto is similar to EntityInfoFromProto, but it panics when it fails to convert.
type EntityWithRunnabilityInfo ¶
type EntityWithRunnabilityInfo struct {
// See TestInstance for details of the fields.
EntityInfo
SkipReason string `json:"skipReason"`
}
EntityWithRunnabilityInfo is a JSON-serializable description of information of an entity to be used for listing test.
Click to show internal directories.
Click to hide internal directories.