Documentation
¶
Overview ¶
Package testingutil is a kitchen sink of utilities shared by Tast tests and Tast framework.
TODO(crbug.com/1019099): Reorganize utilities.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type PollOptions ¶
type PollOptions struct {
// Timeout specifies the maximum time to poll.
// Non-positive values indicate no timeout (although context deadlines will still be honored).
Timeout time.Duration
// Interval specifies how long to sleep between polling.
// Non-positive values indicate that a reasonable default should be used.
Interval time.Duration
}
PollOptions provides testing.PollOptions.
Click to show internal directories.
Click to hide internal directories.